/*
 * Copyright (c) 2009 EBM Websourcing, http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package org.ow2.petals.registry.core.repository.bo;


import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.Column;
import javax.persistence.OneToOne;
import javax.persistence.ManyToOne;
import org.hibernate.annotations.GenericGenerator;

/**
 * @author Christophe HAMERLING - eBM WebSourcing
 *
 */
@Entity
public class Endpoint {

    private String id;

    /**
     * TODO : Set it as DOM document The description will always be XML
     */
    private String description;

    /**
     * The endpoint name
     */
    private String name;

    private String service;
    
    private String rootRegistry;   
    
    private String path; 
    
    private long creationTime;
    
    private Interface interfaceName;

    /**
     * Endpoint properties
     */
    private Properties properties;

    public Endpoint() {
    }

    /**
     * @return the description
     */
    @Lob
    @Column(length=16777214)
    public String getDescription() {
        return this.description;
    }

    /**
     * @param description
     *            the description to set
     */
    public void setDescription(String description) {
        this.description = description;
    }

    /**
     * @return the name
     */
    public String getName() {
        return this.name;
    }

    /**
     * @param name
     *            the name to set
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * @return the properties
     */
    @OneToOne(fetch = FetchType.EAGER)
    public Properties getProperties() {
        return this.properties;
    }

    /**
     * @param properties
     *            the properties to set
     */
    public void setProperties(Properties properties) {
        this.properties = properties;
    }

    /**
     * @return the id
     */
    @Id
    @GeneratedValue(generator = "system-uuid")
    @GenericGenerator(name = "system-uuid", strategy = "uuid")
    public String getId() {
        return this.id;
    }

    /**
     * @param id
     *            the id to set
     */
    public void setId(String id) {
        this.id = id;
    }
 
    /**
     * @return the service
     */
    public String getService() {
        return this.service;
    }
    /**
     * @param service
     *            the service to set
     */
    public void setService(String service) {
        this.service = service;
    }
    
    /**
     * @return the rootRegistry
     */
    public String getRootRegistry() {
        return rootRegistry;
    }
    /**
     * @param rootRegistry
     *            the rootRegistry to set
     */
    public void setRootRegistry(String rootRegistry) {
        this.rootRegistry = rootRegistry;
    }
    
    /**
     * @return the creationTime
     */
    public long getCreationTime() {
        return creationTime;
    }
    /**
     * @param creationTime
     *            the creationTime to set
     */
    public void setCreationTime(long creationTime) {
        this.creationTime = creationTime;
    }
    
    /**
     * @return the path
     */
    @Column(unique = true)
    public String getPath() {
        return path;
    }
    /**
     * @param path
     *            the path to set
     */
    public void setPath(String path) {
        this.path = path;
    }

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "interface_id")
    public Interface getInterfaceName() {
        return interfaceName;
    }

    public void setInterfaceName(Interface interfaceName) {
        this.interfaceName = interfaceName;
    }

    
}
